## Adrienne Hosek and Lauren Peritz ----------------------------------------
## QJPS 2021 "Local labor markets and party elite"
## Purpose: Replicate Tables 1, 2, and 3
## Update: 15 June 2021


## Preliminary steps -------------------------------------------------------
rm(list=ls(all=T))


# Set your working directory here in place of "~/MyFilePath"
setwd("~/MyFilePath/AH_LP_qjps2021_replication")

# packages
library(sandwich) 
library(lmtest)
library(stargazer)

#### SPONSORSHIP/BILL-LEVEL ANALYSIS -----------------------------------------------------

## Prepare data for sponsorship/bill level analysis -----------------------------------

# Load data 
load("HouseSponsorData.RData")
d_all <-d

# function to normalize the explanatory variables for each model
normalize <- function(var){(var - mean(var))/sd(var)}

# drop neutral bills
d <- d[d$policy.content.final!= 0,]

# assemble data for all trade bills with normalized variables
d.T <- d[c("congress","fips_id", "billno_unique", 
          "policy.content.final", "duty", "no.cosponsor", 
          "bioguide_id", "dem", "dim1", "dim2", "majority", 
          "oncom", "gatekeeper", "rollcalls")]

# normalized covariates for all trade bills
d.T$income <- normalize(log(d$income))
d.T$employed <- normalize(d$employed2554)
d.T$nhitype_2554 <- normalize(d$nhitype_2554)
d.T$exp<-normalize(d$exp)
d.T$exp_MFG <-normalize(d$exp_MFG)
d.T$exp_nonMFG <-normalize(d$exp_nonMFG)
d.T$imp<-normalize(d$imp)
d.T$imp_MFG <-normalize(d$imp_MFG)
d.T$imp_nonMFG <-normalize(d$imp_nonMF)

# assemble data for all _non-duty_ trade bills with normalized variables
d.TND <- subset(d, select = c("congress","fips_id", "billno_unique", 
           "policy.content.final", "duty", "no.cosponsor", 
           "bioguide_id", "dem", "dim1", "dim2", "majority", 
           "oncom", "gatekeeper", "rollcalls"), duty==0)


# normalized covariates for _non-duty_ trade bills
d.TND$income <- normalize(log(d$income[d$duty == 0]))
d.TND$employed <- normalize(d$employed2554[d$duty == 0])
d.TND$nhitype_2554 <- normalize(d$nhitype_2554[d$duty == 0])
d.TND$exp<-normalize(d$exp[d$duty == 0])
d.TND$exp_MFG <-normalize(d$exp_MFG[d$duty == 0])
d.TND$exp_nonMFG <-normalize(d$exp_nonMFG[d$duty == 0])
d.TND$imp<-normalize(d$imp[d$duty == 0])
d.TND$imp_MFG <-normalize(d$imp_MFG[d$duty == 0])
d.TND$imp_nonMFG <-normalize(d$imp_nonMF[d$duty == 0])

## TABLE 1 -------------------------------------------------

table(d_all$congress)
nrow(d_all)


## TABLE 2 --------------------------------------------------

# regressions, all trade bills
reg2.T <- lm(policy.content.final ~ dem + dim1 + dim2 + gatekeeper + majority + income + employed, d= d.T)
reg3.T <- lm(policy.content.final ~ dem + imp + exp + gatekeeper + majority + income + employed, d= d.T)
reg3.Tint <- lm(policy.content.final  ~  imp*dem + exp*dem + gatekeeper + majority + income + employed, d= d.T)
reg4.T <- lm(policy.content.final ~ dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + gatekeeper + majority + income + employed, d= d.T)
reg4.Tint <- lm(policy.content.final  ~  imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + gatekeeper + majority + income + employed, d= d.T)
reg8.T <- lm(policy.content.final ~ dem + nhitype_2554 + gatekeeper + majority + income + employed, d = d.T)
reg8.Tint <- lm(policy.content.final ~ nhitype_2554*dem + gatekeeper + majority + income + employed, d = d.T)

# regressions, non-duty trade bills
reg2.TND <- lm(policy.content.final~dem + dim1 + dim2 + gatekeeper + majority + income + employed, d= d.TND)
reg3.TND <- lm(policy.content.final~dem + imp + exp + gatekeeper + majority + income + employed, d= d.TND)
reg3.TNDint <- lm(policy.content.final~imp*dem +  exp*dem + dem + gatekeeper + majority + income + employed, d= d.TND)
reg4.TND <- lm(policy.content.final~dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + gatekeeper + majority + income + employed, d= d.TND)
reg4.TNDint <- lm(policy.content.final~imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + dem + gatekeeper + majority + income + employed, d= d.TND)

# cluster standard errors
c2.T<- coeftest(reg2.T, vcov=vcovCL(reg2.T, factor(d.T$fips_id) ))
c3.T<- coeftest(reg3.T, vcov=vcovCL(reg3.T, factor(d.T$fips_id) ))
c3.Tint<- coeftest(reg3.Tint, vcov=vcovCL(reg3.Tint, factor(d.T$fips_id) ))
c4.T<- coeftest(reg4.T, vcov=vcovCL(reg4.T, factor(d.T$fips_id) ))
c4.Tint<- coeftest(reg4.Tint, vcov=vcovCL(reg4.Tint, factor(d.T$fips_id) ))
c8.T<- coeftest(reg8.T, vcov=vcovCL(reg8.T, factor(d.T$fips_id) ))
c8.Tint<- coeftest(reg8.Tint, vcov=vcovCL(reg8.Tint, factor(d.T$fips_id) ))

c2.TND<- coeftest(reg2.TND, vcov=vcovCL(reg2.TND, factor(d.TND$fips_id) ))
c3.TND<- coeftest(reg3.TND, vcov=vcovCL(reg3.TND, factor(d.TND$fips_id) ))
c3.TNDint<- coeftest(reg3.TNDint, vcov=vcovCL(reg3.TNDint, factor(d.TND$fips_id) ))
c4.TND<- coeftest(reg4.TND, vcov=vcovCL(reg4.TND, factor(d.TND$fips_id) ))
c4.TNDint<- coeftest(reg4.TNDint, vcov=vcovCL(reg4.TNDint, factor(d.TND$fips_id) ))


# view full regression results
stargazer(c2.T, c3.T, c3.Tint, c4.T, c4.Tint, c8.T, c8.Tint, c2.TND, c3.TND, c3.TNDint, c4.TND, c4.TNDint, no.space=T, type="text")

# compact table 2
cov_keep <- c("dem", "dim1", "dim2","imp", "exp", "imp_MFG", "imp_nonMFG","exp_MFG", "exp_nonMFG", "nhitype_2554")
cov_ord <- c("^dem$", "^dim1$", "^dim2$", "^imp$", "^imp:dem$", "^imp_MFG$", "^imp_MFG:dem$", "^imp_nonMFG$", "^dem:imp_nonMFG$",
             "^exp$", "^dem:exp$", "^exp_MFG$", "^dem:exp_MFG$", "^exp_nonMFG$", "^dem:exp_nonMFG$", "^nhitype_2554$", "^nhitype_2554:dem$")
cov_lab <- c("Democratic Sponsor", "DW Nominate Dim. 1", "DW Nominate Dim. 2", 
             "Imports", "\\hspace{10mm} $\\times$ Democrat", "Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat", "Non-Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat",
             "Exports", "\\hspace{10mm} $\\times$ Democrat", "Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", "Non-Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Industry Concentration", "\\hspace{10mm} $\\times$ Democrat")


stargazer(c2.T, c3.T, c3.Tint, c4.T, c4.Tint, c8.T, c8.Tint, c2.TND, c3.TND, c3.TNDint, c4.TND, c4.TNDint, 
          no.space=T, 
          type="latex", 
          title = "Linear Regression of Policy Content of Trade Legislation on District Characteristics", 
          out.header = T, 
          star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, 
          dep.var.caption = "Trade", 
          column.labels = c("Protectionist = 1, Liberalizing = -1","Protectionist = 1, Liberalizing = -1"), 
          column.separate = c(7,5), 
          font.size = "scriptsize", 
          notes.append = T, 
          keep = cov_keep, 
          order = cov_ord, 
          covariate.labels = cov_lab, 
          multicolumn = F, 
          label = "tab:sponsor")

# additional information for table 2
#bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.T$billno_unique)), 7), 
                                     rep(length(unique(d.TND$billno_unique)), 5))))))

#legislators
cat(c("Sponsors", paste(" & ",formatC(c(rep(length(unique(d.T$bioguide_id)), 7), 
                                        rep(length(unique(d.TND$bioguide_id)), 5))))))
#R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg2.T)$r.squared, 
                                    summary(reg3.T)$r.squared, 
                                    summary(reg3.Tint)$r.squared, 
                                    summary(reg4.T)$r.squared, 
                                    summary(reg4.Tint)$r.squared, 
                                    summary(reg8.T)$r.squared, 
                                    summary(reg8.Tint)$r.squared, 
                                    summary(reg2.TND)$r.squared, 
                                    summary(reg3.TND)$r.squared, 
                                    summary(reg3.TNDint)$r.squared, 
                                    summary(reg4.TND)$r.squared, 
                                    summary(reg4.TNDint)$r.squared), 3))))


rm(list=ls(all=T))

#### COSPONSORSHIP/MEMBER-LEVEL ANALYSIS -----------------------------------------------------

## Prepare data for cosponsorship/member level analysis -----------------------------------

# Load data 
load("HouseMemberData.RData")

# drop duty bills; sponsors cannot cosponsor own bill
d <- d[d$duty==0 & d$sp==0,]

# function to normalize the explanatory variables for each model
normalize <- function(var){(var - mean(var))/sd(var)}

# assemble data for non-duty trade protection bills 
d.TP <- d[d$policy.content.final == 1, c("co", "no.cosponsor", "dem", 
                                        "samepartysp", "sp_gatekeeper", 
                                        "sp_majority", "policy.content.final", 
                                        "fips_id", "dim1", "dim2", 
                                        "billno_unique", "bioguide_id","congress")]

d.TP$income <- normalize(log(d$income[d$policy.content.final == 1]))
d.TP$employed <- normalize(d$employed2554[d$policy.content.final == 1])
d.TP$imp <-  normalize(d$imp[d$policy.content.final == 1])
d.TP$exp <-  normalize(d$exp[d$policy.content.final == 1])
d.TP$agr <- normalize(d$AGR_2554[d$policy.content.final == 1])
d.TP$mfg <- normalize(d$MFG_2554[d$policy.content.final == 1])
d.TP$ent <- normalize(d$ENT_2554[d$policy.content.final == 1])
d.TP$prf_fin <- normalize(d$prf_fin[d$policy.content.final == 1])

# assemble data for non-duty trade liberalizing bills 
d.TL <- d[d$policy.content.final == -1, c("co", "no.cosponsor", "dem", 
                                         "samepartysp", "sp_gatekeeper", 
                                         "sp_majority", "policy.content.final", 
                                         "fips_id", "dim1", "dim2", 
                                         "billno_unique", "bioguide_id","congress")]

d.TL$income <- normalize(log(d$income[d$policy.content.final == -1]))
d.TL$employed <- normalize(d$employed2554[d$policy.content.final == -1])
d.TL$imp <-  normalize(d$imp[d$policy.content.final == -1])
d.TL$exp <-  normalize(d$exp[d$policy.content.final == -1])
d.TL$agr <- normalize(d$AGR_2554[d$policy.content.final == -1])
d.TL$mfg <- normalize(d$MFG_2554[d$policy.content.final == -1])
d.TL$ent <- normalize(d$ENT_2554[d$policy.content.final == -1])
d.TL$prf_fin <- normalize(d$prf_fin[d$policy.content.final == -1])


## TABLE 3 --------------------------------------------------

reg2.TP <- lm(co ~ dem + dim1 + dim2 + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg3.TP <- lm(co ~ dem + imp + exp  + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg3.TPint <- lm(co ~  imp*dem + exp*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg4.TP <- lm(co ~ dem + agr + mfg + ent + prf_fin + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg4.TPint <- lm(co ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + employed, d= d.TP)

reg2.TL <- lm(co ~ dem + dim1 + dim2 + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg3.TL <- lm(co ~ dem + imp + exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg3.TLint <- lm(co ~  imp*dem + exp*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg4.TL <- lm(co ~ dem + agr + mfg + ent + prf_fin + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg4.TLint <- lm(co ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)


# cluster standard errors
c2.TP<- coeftest(reg2.TP, vcov=vcovCL(reg2.TP, factor(d.TP$fips_id) ))
c3.TP<- coeftest(reg3.TP, vcov=vcovCL(reg3.TP, factor(d.TP$fips_id) ))
c3.TPint<- coeftest(reg3.TPint, vcov=vcovCL(reg3.TPint, factor(d.TP$fips_id) ))
c4.TP<- coeftest(reg4.TP, vcov=vcovCL(reg4.TP, factor(d.TP$fips_id) ))
c4.TPint<- coeftest(reg4.TPint, vcov=vcovCL(reg4.TPint, factor(d.TP$fips_id) ))

c2.TL<- coeftest(reg2.TL, vcov=vcovCL(reg2.TL, factor(d.TL$fips_id) ))
c3.TL<- coeftest(reg3.TL, vcov=vcovCL(reg3.TL, factor(d.TL$fips_id) ))
c3.TLint<- coeftest(reg3.TLint, vcov=vcovCL(reg3.TLint, factor(d.TL$fips_id) ))
c4.TL<- coeftest(reg4.TL, vcov=vcovCL(reg4.TL, factor(d.TL$fips_id) ))
c4.TLint<- coeftest(reg4.TLint, vcov=vcovCL(reg4.TLint, factor(d.TL$fips_id) ))




# view full regression results
stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint, no.space=T,type="text", star.cutoffs = c(0.05, 0.01, 0.001), digits=3)

# compact table 3
cov_keep <- c("dem", "dim1", "dim2", "imp", "exp", "agr", "mfg", "ent", "prf_fin", "Constant")
cov_ord <- c("^dem$", "^dim1$", "^dim2$", "^imp$", "^imp:dem$","^exp$","^dem:exp$", "^agr$", "^agr:dem$", 
             "^mfg$", "^dem:mfg$", "^ent$", "^dem:ent$", "^prf_fin$", "^dem:prf_fin$")
cov_lab <- c("Democratic Cosponsor", "DW Nominate Dim. 1", "DW Nominate Dim. 2", 
             "Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Agriculture", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing", "\\hspace{10mm} $\\times$ Democrat", 
             "Entertainment", "\\hspace{10mm} $\\times$ Democrat", 
             "Professional and Financial", "\\hspace{10mm} $\\times$ Democrat")


stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint, 
          no.space=T, 
          type="latex", 
          title = "Linear Regression of Decision to Cosponsor Trade Bills (Non-Duty) on District Characteristics", 
          out.header = T, 
          star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, 
          dep.var.caption = "Cosponsorship Indicator", 
          column.labels = c("Trade Protectionist", "Trade Liberalizing"), 
          column.separate = c(5, 5), 
          font.size = "scriptsize", 
          notes.append = F, 
          keep = cov_keep, 
          order = cov_ord, 
          covariate.labels = cov_lab, 
          multicolumn = F, 
          label = "tab:mem-tr")


#additional information for table 3
#N
cat(c("N", paste(" & ",formatC(c(rep(dim(d.TP)[1], 5), rep(dim(d.TL)[1], 5)), format = "d", big.mark = ","))))

#bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.TP$billno_unique)), 5), rep(length(unique(d.TL$billno_unique)), 5)), format = "d", big.mark = ","))))

#legislators
cat(c("Legislators", paste(" & ",formatC(c(rep(length(unique(d.TP$bioguide_id)), 5), rep(length(unique(d.TL$bioguide_id)), 5)), format = "d", big.mark = ","))))

#R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg2.TP)$r.squared, summary(reg3.TP)$r.squared, summary(reg3.TPint)$r.squared, summary(reg4.TP)$r.squared, summary(reg4.TPint)$r.squared, summary(reg2.TL)$r.squared, summary(reg3.TL)$r.squared, summary(reg3.TLint)$r.squared, summary(reg4.TL)$r.squared, summary(reg4.TLint)$r.squared), 2))))





