## Adrienne Hosek and Lauren Peritz ----------------------------------------
## QJPS 2021 "Local labor markets and party elite"
## Purpose: Replicate Tables A1, A2, ..., A9
## Update: 15 June 2021


## Preliminary steps -------------------------------------------------------

rm(list=ls(all=T))

# Set your working directory here in place of "~/MyFilePath"
setwd("~/MyFilePath/AH_LP_qjps2021_replication")


#  Huber-white adjustments
library(lmtest)
library(sandwich) 

# Nice tables
library(stargazer)



#### SPONSORSHIP/BILL-LEVEL ANALYSIS -----------------------------------------------------

# load sponsor data
load("HouseSponsorData.RData")


## Prepare data for sponsorship/bill level analysis -----------------------------------

# function to normalize the explanatory variables for each model
normalize <- function(var){(var - mean(var))/sd(var)}

# trade bill data including duty bills
d.T <- d[d$policy.content.final != 0,]


# normalized covariates
d.T$wtb<-normalize( d.T$wtb)
d.T$wtb_MFG <-normalize( d.T$wtb_MFG)
d.T$wtb_nonMFG <-normalize( d.T$wtb_nonMFG)

d.T$exp<-normalize( d.T$exp)
d.T$exp_MFG <-normalize( d.T$exp_MFG)
d.T$exp_AGR <-normalize( d.T$exp2554_AGR)
d.T$exp_EXT <-normalize( d.T$exp2554_EXT) 
d.T$exp_nonMFG <-normalize( d.T$exp_nonMFG)

d.T$imp<-normalize( d.T$imp)
d.T$imp_MFG <-normalize( d.T$imp_MFG)
d.T$imp_AGR <-normalize( d.T$imp2554_AGR)
d.T$imp_EXT <-normalize( d.T$imp2554_EXT) 
d.T$imp_nonMFG <-normalize( d.T$imp_nonMFG)

d.T$agr <- normalize( d.T$AGR_2554 )
d.T$mfg <- normalize( d.T$MFG_2554 )
d.T$ent <- normalize( d.T$ENT_2554 )
d.T$prf_fin <- normalize( d.T$prf_fin )
d.T$income <- normalize(log( d.T$income) )
d.T$employed <- normalize( d.T$employed2554 )
d.T$occpz_low <- normalize( d.T$occpz_low )
d.T$occpz_mid <- normalize( d.T$occpz_mid )
d.T$nhitype_2554 <- normalize( d.T$nhitype_2554 )
d.T$indprim_2554 <- normalize( d.T$indprim_2554 )
d.T$indsec_2554 <- normalize( d.T$indsec_2554 )
d.T$indtert_2554 <- normalize( d.T$indtert_2554 )


##### Trade Bill Data excluding duty bills
d.TND <- d[d$policy.content.final != 0 & d$duty == 0, ]


# normalized covariates
d.TND$wtb<-normalize(  d.TND$wtb)
d.TND$wtb_MFG <-normalize(  d.TND$wtb_MFG)
d.TND$wtb_nonMFG <-normalize(  d.TND$wtb_nonMFG)

d.TND$exp<-normalize(  d.TND$exp)
d.TND$exp_MFG <-normalize(  d.TND$exp_MFG)
d.TND$exp_AGR <-normalize(  d.TND$exp2554_AGR)
d.TND$exp_EXT <-normalize(  d.TND$exp2554_EXT) 
d.TND$exp_nonMFG <-normalize(  d.TND$exp_nonMFG)

d.TND$imp<-normalize(  d.TND$imp)
d.TND$imp_MFG <-normalize(  d.TND$imp_MFG)
d.TND$imp_AGR <-normalize(  d.TND$imp2554_AGR)
d.TND$imp_EXT <-normalize(  d.TND$imp2554_EXT) 
d.TND$imp_nonMFG <-normalize(  d.TND$imp_nonMFG)

d.TND$agr <- normalize(  d.TND$AGR_2554 )
d.TND$mfg <- normalize(  d.TND$MFG_2554 )
d.TND$ent <- normalize(  d.TND$ENT_2554 )
d.TND$prf_fin <- normalize(  d.TND$prf_fin )
d.TND$income <- normalize(log(  d.TND$income) )
d.TND$employed <- normalize(  d.TND$employed2554 )
d.TND$occpz_low <- normalize(  d.TND$occpz_low )
d.TND$occpz_mid <- normalize(  d.TND$occpz_mid )
d.TND$nhitype_2554 <- normalize(  d.TND$nhitype_2554 )
d.TND$indprim_2554 <- normalize(  d.TND$indprim_2554 )
d.TND$indsec_2554 <- normalize(  d.TND$indsec_2554 )
d.TND$indtert_2554 <- normalize(  d.TND$indtert_2554 )

## Table A.1--------------------------------------------------------------------------

# including duty bills regressions
reg1.T <- lm(policy.content.final ~ dem + gatekeeper + majority + income + employed, d= d.T)
reg5.T <- lm(policy.content.final ~ dem + agr + mfg + ent + prf_fin + gatekeeper + majority + income + employed, d= d.T)
reg6.T <- lm(policy.content.final ~ dem + occpz_low + occpz_mid + gatekeeper + majority + income + employed, d= d.T)
reg7.T <- lm(policy.content.final ~ dem + imp_AGR + imp_MFG + imp_EXT + exp_AGR + exp_MFG + exp_EXT + gatekeeper + majority + income + employed, d= d.T)
reg5.Tint <- lm(policy.content.final  ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem  + gatekeeper + majority + income + employed, d= d.T)
reg6.Tint <-lm(policy.content.final  ~ occpz_low*dem + occpz_mid*dem + gatekeeper + majority + income + employed, d= d.T)
reg7.Tint <- lm(policy.content.final  ~ imp_AGR*dem + imp_EXT*dem + imp_MFG*dem + exp_AGR*dem + exp_EXT*dem + exp_MFG*dem + gatekeeper + majority + income + employed, d= d.T)


# cluster on member of congress 
c1.T <- coeftest(reg1.T, vcov=vcovCL(reg1.T, factor(d.T$fips_id)))
c5.T <- coeftest(reg5.T, vcov=vcovCL(reg5.T, factor(d.T$fips_id)))
c6.T <- coeftest(reg6.T, vcov=vcovCL(reg6.T, factor(d.T$fips_id)))
c7.T <- coeftest(reg7.T, vcov=vcovCL(reg7.T, factor(d.T$fips_id)))
c5.Tint <- coeftest(reg5.Tint, vcov=vcovCL(reg5.Tint, factor(d.T$fips_id)))
c6.Tint <- coeftest(reg6.Tint, vcov=vcovCL(reg6.Tint, factor(d.T$fips_id)))
c7.Tint <- coeftest(reg7.Tint, vcov=vcovCL(reg7.Tint, factor(d.T$fips_id)))


# table
stargazer(c1.T, c5.T, c5.Tint,c6.T, c6.Tint, c7.T, c7.Tint, no.space=T, type="text")

# covariate order and labels for trade bills
cov_keep <- c("dem", "agr", "mfg", "ent", "prf_fin", "occpz_low", "occpz_mid", "imp_AGR","imp_MFG","imp_EXT","exp_AGR","exp_MFG","exp_EXT", "Constant")
cov_ord <- c("^dem$", 
             "^agr$", "^agr:dem$", "^mfg$","^dem:mfg$", "^ent$","^dem:ent$","^prf_fin$","^dem:prf_fin$", 
             "^occpz_low$","^occpz_low:dem$", "^occpz_mid$","^dem:occpz_mid$", 
             "^imp_AGR$","^imp_AGR:dem$","^imp_MFG$", "^dem:imp_MFG$","^imp_EXT$","^dem:imp_EXT$",
             "^exp_AGR$","^dem:exp_AGR$","^exp_MFG$", "^dem:exp_MFG$","^exp_EXT$","^dem:exp_EXT$",
             "^Constant$")
cov_lab <- c("Democratic Sponsor", 
             "Agriculture Employment", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Entertainment Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Professional/Financial Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Low-Skill Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Mid-Skill Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Agriculture Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Extraction Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Agriculture Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Extraction Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Constant")


stargazer(c1.T, c5.T, c5.Tint, c6.T, c6.Tint, c7.T, c7.Tint,
          no.space=T, 
          type="latex", 
          title = "Linear Regression of Policy Content of Trade Legislation on District Characteristics, $109^{th} - 114^{th}$ Congress", 
          out.header = T, 
          star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, 
          dep.var.caption = "Trade", 
          column.labels = "Protectionist = 1, Liberalizing = -1", 
          column.separate = 5, 
          font.size = "scriptsize", 
          notes.append = T, 
          keep = cov_keep, 
          order = cov_ord, 
          covariate.labels = cov_lab, 
          multicolumn = F, 
          label = "tab:sponsor-tr-appdx")


#additional information for table
#bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.T$billno_unique)), 7))))))

#legislators
cat(c("Sponsors", paste(" & ",formatC(c(rep(length(unique(d.T$bioguide_id)), 7))))))

#R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg1.T)$r.squared, 
                                    summary(reg5.T)$r.squared, 
                                    summary(reg5.Tint)$r.squared, 
                                    summary(reg6.T)$r.squared, 
                                    summary(reg6.Tint)$r.squared, 
                                    summary(reg7.T)$r.squared, 
                                    summary(reg7.Tint)$r.squared), 3))))


##Table A.2---------------------------------------------------------------------------------


# excluding duty bills regressions
reg1.TND <- lm(policy.content.final~dem + gatekeeper + majority + income + employed, d= d.TND)
reg5.TND <- lm(policy.content.final~dem + agr + mfg + ent + prf_fin + gatekeeper + majority + income + employed, d= d.TND)
reg6.TND <- lm(policy.content.final~dem + occpz_low + occpz_mid + gatekeeper + majority + income + employed, d= d.TND)
reg7.TND <- lm(policy.content.final~dem + imp_AGR + imp_MFG + imp_EXT + exp_AGR + exp_MFG + exp_EXT + gatekeeper + majority + income + employed, d= d.TND)
reg5.TNDint <- lm(policy.content.final~agr*dem + mfg*dem + ent*dem + prf_fin*dem + gatekeeper + majority + income + employed, d= d.TND)
reg6.TNDint <- lm(policy.content.final~dem + occpz_low*dem + occpz_mid*dem + gatekeeper + majority + income + employed, d= d.TND)
reg7.TNDint <- lm(policy.content.final~imp_AGR*dem + imp_EXT*dem + imp_MFG*dem + exp_AGR*dem + exp_MFG*dem + exp_EXT*dem + gatekeeper + majority + income + employed, d= d.TND)


# cluster on member of congress 
c1.TND <- coeftest(reg1.TND, vcov=vcovCL(reg1.TND, factor(d.TND$fips_id)))
c5.TND <- coeftest(reg5.TND, vcov=vcovCL(reg5.TND, factor(d.TND$fips_id)))
c6.TND <- coeftest(reg6.TND, vcov=vcovCL(reg6.TND, factor(d.TND$fips_id)))
c7.TND <- coeftest(reg7.TND, vcov=vcovCL(reg7.TND, factor(d.TND$fips_id)))
c5.TNDint <- coeftest(reg5.TNDint, vcov=vcovCL(reg5.TNDint, factor(d.TND$fips_id)))
c6.TNDint <- coeftest(reg6.TNDint, vcov=vcovCL(reg6.TNDint, factor(d.TND$fips_id)))
c7.TNDint <- coeftest(reg7.TNDint, vcov=vcovCL(reg7.TNDint, factor(d.TND$fips_id)))



# table
stargazer(c1.TND, c5.TND, c5.TNDint, c6.TND, c6.TNDint, c7.TND, c7.TNDint,  no.space=T, type="text")

# covariate order and labels for trade bills
cov_keep <- c("dem", "agr", "mfg", "ent", "prf_fin", "occpz_low", "occpz_mid", "imp_AGR","imp_MFG","imp_EXT","exp_AGR","exp_MFG","exp_EXT", "Constant")
cov_ord <- c("^dem$", 
             "^agr$", "^agr:dem$", "^mfg$","^dem:mfg$", "^ent$","^dem:ent$","^prf_fin$","^dem:prf_fin$", 
             "^occpz_low$","^dem:occpz_low$", "^occpz_mid$","^dem:occpz_mid$", 
             "^imp_AGR$","^imp_AGR:dem$","^imp_MFG$", "^dem:imp_MFG$","^imp_EXT$","^dem:imp_EXT$",
             "^exp_AGR$","^dem:exp_AGR$","^exp_MFG$", "^dem:exp_MFG$","^exp_EXT$","^dem:exp_EXT$",
             "^Constant$")
cov_lab <- c("Democratic Sponsor", 
             "Agriculture Employment", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Entertainment Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Professional/Financial Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Low-Skill Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Mid-Skill Employment", "\\hspace{10mm} $\\times$ Democrat",
             "Agriculture Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Extraction Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Agriculture Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Extraction Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Constant")



stargazer(c1.TND, c5.TND, c5.TNDint, c6.TND, c6.TNDint, c7.TND, c7.TNDint,
          no.space=T, 
          type="latex", 
          title = "Linear Regression of Policy Content of Trade Legislation on District Characteristics, $109^{th} - 114^{th}$ Congress", 
          out.header = T, 
          star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, 
          dep.var.caption = "Trade", 
          column.labels = "Protectionist = 1, Liberalizing = -1", 
          column.separate = 5, 
          font.size = "scriptsize", 
          notes.append = T, 
          keep = cov_keep, 
          order = cov_ord, 
          covariate.labels = cov_lab, 
          multicolumn = F, 
          label = "tab:sponsor-tr-appdx")

#additional information for table
#bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.TND$billno_unique)), 7))))))

#legislators
cat(c("Sponsors", paste(" & ",formatC(c(rep(length(unique(d.TND$bioguide_id)), 7))))))

#R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg1.TND)$r.squared, 
                                    summary(reg5.TND)$r.squared, 
                                    summary(reg5.TNDint)$r.squared, 
                                    summary(reg6.TND)$r.squared, 
                                    summary(reg6.TNDint)$r.squared, 
                                    summary(reg7.TND)$r.squared, 
                                    summary(reg7.TNDint)$r.squared), 3))))

##Table A.3--------------------------------------------------------------------------------


d.T$policy.content.f <- ifelse(d.T$policy.content.final==1,1,0) # 1 = protectionist; 0 = liberalizing
d.TND$policy.content.f <- ifelse(d.TND$policy.content.final==1,1,0) # 1 = protectionist; 0 = liberalizing

# including duty bills logistic regressions
log2.T <- glm(policy.content.f ~ dem + dim1 + dim2 + gatekeeper + majority + income + employed, d= d.T, family = 'binomial')
log3.T <- glm(policy.content.f ~ dem + imp + exp + gatekeeper + majority + income + employed, d= d.T, family = 'binomial')
log4.T <- glm(policy.content.f ~ dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + gatekeeper + majority + income + employed, d= d.T, family = 'binomial')
log3.Tint <- glm(policy.content.f ~ imp*dem + exp*dem + gatekeeper + majority + income + employed, d= d.T, family = 'binomial')
log4.Tint <- glm(policy.content.f ~ imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + gatekeeper + majority + income + employed, d= d.T, family = 'binomial')

# cluster on member of congress 
c2.T <- coeftest(log2.T, vcov. = vcovCL(log2.T, cluster = d.T$fips_id, type = "HC0"))
c3.T <- coeftest(log3.T, vcov. = vcovCL(log3.T, cluster = d.T$fips_id, type = "HC0"))
c4.T <- coeftest(log4.T, vcov. = vcovCL(log4.T, cluster = d.T$fips_id, type = "HC0"))
c3.Tint <- coeftest(log3.Tint, vcov. = vcovCL(log3.Tint, cluster = d.T$fips_id, type = "HC0"))
c4.Tint <- coeftest(log4.Tint, vcov. = vcovCL(log4.Tint, cluster = d.T$fips_id, type = "HC0"))

### excluding duty bills logistic regressions
log2.TND <- glm(policy.content.f~dem + dim1 + dim2 + gatekeeper + majority + income + employed, d= d.TND, family = 'binomial')
log3.TND <- glm(policy.content.f~dem + imp + exp + gatekeeper + majority + income + employed, d= d.TND, family = 'binomial')
log4.TND <- glm(policy.content.f~dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + gatekeeper + majority + income + employed, d= d.TND, family = 'binomial')
log3.TNDint <- glm(policy.content.f~imp*dem + exp*dem  + dem + gatekeeper + majority + income + employed, d= d.TND, family = 'binomial')
log4.TNDint <- glm(policy.content.f~imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + dem + gatekeeper + majority + income + employed, d= d.TND, family = 'binomial')

# cluster on member of congress 
c2.TND <- coeftest(log2.TND, vcov. = vcovCL(log2.TND, cluster = d.TND$fips_id, type = "HC0"))
c3.TND <- coeftest(log3.TND, vcov. = vcovCL(log3.TND, cluster = d.TND$fips_id, type = "HC0"))
c4.TND <- coeftest(log4.TND, vcov. = vcovCL(log4.TND, cluster = d.TND$fips_id, type = "HC0"))
c3.TNDint <- coeftest(log3.TNDint, vcov. = vcovCL(log3.TNDint, cluster = d.TND$fips_id, type = "HC0"))
c4.TNDint <- coeftest(log4.TNDint, vcov. = vcovCL(log4.TNDint, cluster = d.TND$fips_id, type = "HC0"))

#### Repeat Table 2 in main paper using ordered logistic model:
stargazer(c2.T, c3.T, c3.Tint, c4.T, c4.Tint, no.space=T, type="text")
stargazer(c2.TND, c3.TND, c3.TNDint, c4.TND, c4.TNDint, no.space=T, type="text")


#covariate order and labels for trade bills
cov_keep <- c("dem", "dim1", "dim2","imp", "exp", "imp_MFG", "imp_nonMFG", "exp_MFG", "exp_nonMFG", "Constant")
cov_ord <- c("^dem$", "^dim1$", "^dim2$", "^imp$", "^imp:dem$", 
             "^imp_MFG$", "^imp_MFG:dem$", "^imp_nonMFG$", "^dem:imp_nonMFG$",
             "^exp$", "^dem:exp$", "^exp_MFG$", "^dem:exp_MFG$", "^exp_nonMFG$", "^dem:exp_nonMFG$")
cov_lab <- c("Democratic Sponsor", "DW Nominate Dim. 1", "DW Nominate Dim. 2", 
             "Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat", "Non-Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", "Non-Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Constant")


stargazer(c2.T, c3.T, c3.Tint, c4.T, c4.Tint, c2.TND, c3.TND, c3.TNDint, c4.TND, c4.TNDint, 
          no.space=T, 
          type="latex", 
          title = "Logistic Regression of Policy Content of Trade Legislation on District Characteristics, $109^{th} - 114^{th}$ Congress", 
          out.header = T, 
          star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, 
          dep.var.caption = "Trade", 
          column.labels = c("Protectionist = 1, Liberalizing = -1","Protectionist = 1, Liberalizing = -1"), 
          column.separate = c(5,5), 
          font.size = "scriptsize", 
          notes.append = T, 
          keep = cov_keep, 
          order = cov_ord, 
          covariate.labels = cov_lab, 
          multicolumn = F, 
          label = "tab:sponsor-tr-logistic")


#additional information for table
#bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.T$billno_unique)), 5), 
                                     rep(length(unique(d.TND$billno_unique)), 5))))))

#legislators
cat(c("Sponsors", paste(" & ",formatC(c(rep(length(unique(d.T$bioguide_id)), 5), 
                                        rep(length(unique(d.TND$bioguide_id)), 5))))))


#R-squared
cat(c("LogLik", paste(" & ", round(c(logLik(log2.T), 
                                     logLik(log3.T), 
                                     logLik(log4.T), 
                                     logLik(log3.Tint), 
                                     logLik(log4.Tint), 
                                     logLik(log2.TND), 
                                     logLik(log3.TND), 
                                     logLik(log4.TND), 
                                     logLik(log3.TNDint), 
                                     logLik(log4.TNDint)), 3))))


###### ROLL CALL VOTE ANALYSIS ------------------------------------------------------

rm(list=ls(all=T))

# Roll Call data
load("HouseRollCallData.RData")


## Prepare data for roll call vote analysis -----------------------------------------

# function to normalize the explanatory variables for each model
normalize <- function(var){(var - mean(var))/sd(var)}

# roll call data for protectionist trade bills
d.TP <- d[d$policy.content.final == 1, ]


# normalize variables
d.TP$wtb <-  normalize(d.TP$wtb)
d.TP$imp <-  normalize(d.TP$imp)
d.TP$imp_MFG <-  normalize(d.TP$imp_MFG)
d.TP$imp_nonMFG <-  normalize(d.TP$imp_nonMFG)
d.TP$exp <-  normalize(d.TP$exp)
d.TP$exp_MFG <-  normalize(d.TP$exp_MFG)
d.TP$exp_nonMFG <-  normalize(d.TP$exp_nonMFG)
d.TP$agr <- normalize(d.TP$AGR_2554)
d.TP$mfg <- normalize(d.TP$MFG_2554)
d.TP$ent <- normalize(d.TP$ENT_2554)
d.TP$prf_fin <- normalize(d.TP$prf_fin)
d.TP$income <- normalize(log(d.TP$income))
d.TP$employed <- normalize(d.TP$employed2554)


# roll call data for liberalizing trade bills
d.TL <- d[d$policy.content.final == -1, ]

# normalize variables
d.TL$wtb <-  normalize(d.TL$wtb)
d.TL$imp <-  normalize(d.TL$imp)
d.TL$imp_MFG <-  normalize(d.TL$imp_MFG)
d.TL$imp_nonMFG <-  normalize(d.TL$imp_nonMFG)
d.TL$exp <-  normalize(d.TL$exp)
d.TL$exp_MFG <-  normalize(d.TL$exp_MFG)
d.TL$exp_nonMFG <-  normalize(d.TL$exp_nonMFG)
d.TL$agr <- normalize(d.TL$AGR_2554)
d.TL$mfg <- normalize(d.TL$MFG_2554)
d.TL$ent <- normalize(d.TL$ENT_2554)
d.TL$prf_fin <- normalize(d.TL$prf_fin)
d.TL$income <- normalize(log(d.TL$income))
d.TL$employed <- normalize(d.TL$employed2554)




##Table A.4--------------------------------------------------------------------



# protectionist bill regressions
reg2.TP <- lm(support ~ dem + dim1 + dim2 + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg3.TP <- lm(support ~ dem + imp + exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg4.TP <- lm(support ~ dem + agr + mfg + ent + prf_fin + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg5.TP <- lm(support ~ dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg3.TPint <- lm(support ~  imp*dem + exp*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg4.TPint <- lm(support ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg5.TPint <- lm(support ~ imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)

# cluster on member of congress 
c2.TP <- coeftest(reg2.TP, vcov=vcovCL(reg2.TP, factor(d.TP$fips_id)))
c3.TP <- coeftest(reg3.TP, vcov=vcovCL(reg3.TP, factor(d.TP$fips_id)))
c4.TP <- coeftest(reg4.TP, vcov=vcovCL(reg4.TP, factor(d.TP$fips_id)))
c5.TP <- coeftest(reg5.TP, vcov=vcovCL(reg5.TP, factor(d.TP$fips_id)))
c3.TPint <- coeftest(reg3.TPint, vcov=vcovCL(reg3.TPint, factor(d.TP$fips_id)))
c4.TPint <- coeftest(reg4.TPint, vcov=vcovCL(reg4.TPint, factor(d.TP$fips_id)))
c5.TPint <- coeftest(reg5.TPint, vcov=vcovCL(reg5.TPint, factor(d.TP$fips_id)))


# protectionist bill table
stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, c5.TP, c5.TPint, no.space = T, type = "text")

# roll calls for each protectionist bill
bob<-table(d.TP$support,d.TP$billno_unique)
round(bob[2,]/(bob[1,]+bob[2,]), digits = 3 )*100

#covariate order and labels for trade bills
cov_keep <- c("dem", "dim1", "dim2", "imp", "exp", "agr", "mfg", "ent", "prf_fin", "imp_MFG", "imp_nonMFG",
              "exp_MFG", "exp_nonMFG", "Constant")
cov_ord <- c("^dem$", "^dim1$", "^dim2$", "^imp$", "^imp:dem$","^exp$","^dem:exp$", "^agr$", "^agr:dem$", 
             "^mfg$", "^dem:mfg$", "^ent$", "^dem:ent$", "^prf_fin$", "^dem:prf_fin$", "^imp_MFG$", 
             "^imp_MFG:dem$", "^imp_nonMFG$", "^dem:imp_nonMFG$", "^exp_MFG$", "^dem:exp_MFG$", 
             "^exp_nonMFG$", "^dem:exp_nonMFG$", "^Constant$")
cov_lab <- c("Democratic Cosponsor", "DW Nominate Dim. 1", "DW Nominate Dim. 2", 
             "Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Agriculture", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing", "\\hspace{10mm} $\\times$ Democrat", 
             "Entertainment", "\\hspace{10mm} $\\times$ Democrat", 
             "Professional and Financial", "\\hspace{10mm} $\\times$ Democrat", 
             "Manuf. Imports", "\\hspace{10mm} $\\times$ Democrat",
             "Non-Manuf. Imports", "\\hspace{10mm} $\\times$ Democrat",
             "Manuf. Exports", "\\hspace{10mm} $\\times$ Democrat",
             "Non-Manuf. Exports", "\\hspace{10mm} $\\times$ Democrat",
             "Constant")

#condensed main and interaction effects, Liberalizing
stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, c5.TP, c5.TPint, no.space=T, type="latex", star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, dep.var.caption = "Roll Call Vote Indicator", column.labels = c("Trade Protectionist"), column.separate = c(5), 
          font.size = "scriptsize", notes.append = T, keep = cov_keep, order = cov_ord, covariate.labels = cov_lab, multicolumn = F)


#additional information for table
#N
cat(c("N", paste(" & ",formatC(c(rep(dim(d.TP)[1], 7)), format = "d", big.mark = ","))))

#bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.TP$billno_unique)), 7)), format = "d", big.mark = ","))))

#legislators
cat(c("Legislators", paste(" & ",formatC(c(rep(length(unique(d.TP$bioguide_id)), 7)), format = "d", big.mark = ","))))

#R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg2.TP)$r.squared, 
                                    summary(reg3.TP)$r.squared, 
                                    summary(reg3.TPint)$r.squared, 
                                    summary(reg4.TP)$r.squared, 
                                    summary(reg4.TPint)$r.squared, 
                                    summary(reg5.TP)$r.squared, 
                                    summary(reg5.TPint)$r.squared), 2))))


##Table A.5---------------------------------------------------------------------------------

# liberalizing bill regressions
reg2.TL <- lm(support ~ dem + dim1 + dim2 + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg3.TL <- lm(support ~ dem + imp + exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg4.TL <- lm(support ~ dem + agr + mfg + ent + prf_fin + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg5.TL <- lm(support ~ dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg3.TLint <- lm(support ~  imp*dem + exp*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg4.TLint <- lm(support ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + employed, d= d.TL)
reg5.TLint <- lm(support ~ imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)


# cluster on member of congress 
c2.TL <- coeftest(reg2.TL, vcov=vcovCL(reg2.TL, factor(d.TL$fips_id)))
c3.TL <- coeftest(reg3.TL, vcov=vcovCL(reg3.TL, factor(d.TL$fips_id)))
c4.TL <- coeftest(reg4.TL, vcov=vcovCL(reg4.TL, factor(d.TL$fips_id)))
c5.TL <- coeftest(reg5.TL, vcov=vcovCL(reg5.TL, factor(d.TL$fips_id)))
c3.TLint <- coeftest(reg3.TLint, vcov=vcovCL(reg3.TLint, factor(d.TL$fips_id)))
c4.TLint <- coeftest(reg4.TLint, vcov=vcovCL(reg4.TLint, factor(d.TL$fips_id)))
c5.TLint <- coeftest(reg5.TLint, vcov=vcovCL(reg5.TLint, factor(d.TL$fips_id)))


# liberalizing bill table
stargazer(c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint, c5.TL, c5.TLint, no.space = T, type = "text")

# roll call votes for each liberalizing bill
bob <- table(d.TL$support,d.TL$billno_unique)
round(bob[2,]/(bob[1,]+bob[2,]), digits = 3 )*100


# construct latex tables

#covariate order and labels for trade bills
cov_keep <- c("dem", "dim1", "dim2", "imp", "exp", "agr", "mfg", "ent", "prf_fin", "imp_MFG", "imp_nonMFG", "exp_MFG", "exp_nonMFG", "Constant")
cov_ord <- c("^dem$", "^dim1$", "^dim2$", "^imp$", "^imp:dem$", "^exp$", "^dem:exp$" ,
             "^agr$", "^agr:dem$", "^mfg$", "^dem:mfg$", "^ent$", "^dem:ent$", "^prf_fin$", "^dem:prf_fin$", 
             "^imp_MFG$","^imp_MFG:dem$", "^imp_nonMFG$","^dem:imp_nonMFG$", "^exp_MFG$","^dem:exp_MFG$", "^exp_nonMFG$", "^dem:exp_nonMFG$",
             "^Constant$")
cov_lab <- c("Democratic MC", "DW Nominate Dim. 1", "DW Nominate Dim. 2", 
             "Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Agriculture", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing", "\\hspace{10mm} $\\times$ Democrat", 
             "Entertainment", "\\hspace{10mm} $\\times$ Democrat", 
             "Professional and Financial", "\\hspace{10mm} $\\times$ Democrat", 
             "Manuf. Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Non-Manuf. Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manuf. Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Non-Manuf. Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Constant")



#condensed main and interaction effects, Liberalizing
stargazer(c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint, c5.TL, c5.TLint, no.space=T, type="latex", star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, dep.var.caption = "Roll Call Vote Indicator", column.labels = c("Trade Liberalizing"), column.separate = c(5), 
          font.size = "scriptsize", notes.append = T, keep = cov_keep, order = cov_ord, covariate.labels = cov_lab, multicolumn = F)

#additional information for table
#N
cat(c("N", paste(" & ",formatC(c(rep(dim(d.TL)[1], 7)), format = "d", big.mark = ","))))

#bills
cat(c("Bills", paste(" & ",formatC(c( rep(length(unique(d.TL$billno_unique)), 7)), format = "d", big.mark = ","))))

#legislators
cat(c("Legislators", paste(" & ",formatC(c( rep(length(unique(d.TL$name)), 7)), format = "d", big.mark = ","))))

#R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg2.TL)$r.squared, 
                                    summary(reg3.TL)$r.squared, 
                                    summary(reg3.TLint)$r.squared, 
                                    summary(reg4.TL)$r.squared, 
                                    summary(reg4.TLint)$r.squared, 
                                    summary(reg5.TL)$r.squared, 
                                    summary(reg5.TLint)$r.squared), 2))))




## Text Analysis --------------------------------------------------------------------------------
## For the section, Regression of Roll Call Votes on District Characteristics in Appendix

# among protectionist legislation
# top 5% entertainment employment
qtop <- quantile(d.TP$ent, probs = .95)

# states with top 5% entertainment employment by party
sort(with(subset(d.TP, ent >= qtop), table(state)))

# percent rep (0) and dem(0) vote for protectionist legislation among top 5% entertainment employment
with(subset(d.TP, ent >= qtop), tapply(vote_position, dem, function(k) mean(ifelse(k == "Yes", 1, 0))))

# percent rep (0) and dem(0) vote for protectionist legislation among bottom 95% entertainment employment
with(subset(d.TP, ent < qtop), tapply(vote_position, dem, function(k) mean(ifelse(k == "Yes", 1, 0))))

# among liberalizing legislation
# top 5% entertainment employment
qtop <- quantile(d.TL$ent, probs = .95)

# states with top 5% entertainment employment by party
sort(with(subset(d.TL, ent >= qtop), table(state)))

# percent rep (0) and dem(0) vote for protectionist legislation among top 5% entertainment employment
with(subset(d.TL, ent >= qtop), tapply(vote_position, dem, function(k) mean(ifelse(k == "Yes", 1, 0))))

# percent rep (0) and dem(0) vote for protectionist legislation among bottom 95% entertainment employment
with(subset(d.TL, ent < qtop), tapply(vote_position, dem, function(k) mean(ifelse(k == "Yes", 1, 0))))


######################################################################################
###### COSPONSORSHIP ANALYSIS



rm(list=ls(all=T))

# Member data
load("HouseMemberData.RData")

## Prepare data for cosponsorship analysis -----------------------------------------

# function to normalize the explanatory variables for each model
normalize <- function(var){(var - mean(var))/sd(var)}



#  cosponsorship data for trade protection bills
d.TP <- d[d$policy.content.final == 1 & d$sp == 0 & d$duty == 0, ]

# normalize variables
d.TP$wtb <-  normalize(d.TP$wtb)
d.TP$wtb_MFG <-  normalize(d.TP$wtb_MFG)
d.TP$wtb_nonMFG <-  normalize(d.TP$wtb_nonMFG)

d.TP$exp <-  normalize(d.TP$exp)
d.TP$exp_MFG <-  normalize(d.TP$exp_MFG)
d.TP$exp_nonMFG <-  normalize(d.TP$exp_nonMFG)

d.TP$imp <-  normalize(d.TP$imp)
d.TP$imp_MFG <-  normalize(d.TP$imp_MFG)
d.TP$imp_nonMFG <-  normalize(d.TP$imp_nonMFG)

d.TP$agr <- normalize(d.TP$AGR_2554)
d.TP$mfg <- normalize(d.TP$MFG_2554)
d.TP$ent <- normalize(d.TP$ENT_2554)
d.TP$prf_fin <- normalize(d.TP$prf_fin)
d.TP$income <- normalize(log(d.TP$income))
d.TP$employed <- normalize(d.TP$employed2554)

d.TP$occpz_low <- normalize(d.TP$occpz_low)
d.TP$occpz_mid <- normalize(d.TP$occpz_mid)
d.TP$nhitype_2554 <- normalize(d.TP$nhitype_2554)
d.TP$indprim_2554 <- normalize(d.TP$indprim_2554)
d.TP$indsec_2554 <- normalize(d.TP$indsec_2554)
d.TP$indtert_2554 <- normalize(d.TP$indtert_2554)

# cosponsorship data for trade liberalizing bills
d.TL <- d[d$policy.content.final == -1 & d$sp == 0 & d$duty == 0, ]

d.TL$wtb <-  normalize(d.TL$wtb)
d.TL$wtb_MFG <-  normalize(d.TL$wtb_MFG)
d.TL$wtb_nonMFG <-  normalize(d.TL$wtb_nonMFG)

d.TL$exp <-  normalize(d.TL$exp)
d.TL$exp_MFG <-  normalize(d.TL$exp_MFG)
d.TL$exp_nonMFG <-  normalize(d.TL$exp_nonMFG)

d.TL$imp <-  normalize(d.TL$imp)
d.TL$imp_MFG <-  normalize(d.TL$imp_MFG)
d.TL$imp_nonMFG <-  normalize(d.TL$imp_nonMFG)

d.TL$agr <- normalize(d.TL$AGR_2554)
d.TL$mfg <- normalize(d.TL$MFG_2554)
d.TL$ent <- normalize(d.TL$ENT_2554)
d.TL$prf_fin <- normalize(d.TL$prf_fin)
d.TL$income <- normalize(log(d.TL$income))
d.TL$employed <- normalize(d.TL$employed2554)

d.TL$occpz_low <- normalize(d.TL$occpz_low)
d.TL$occpz_mid <- normalize(d.TL$occpz_mid)
d.TL$nhitype_2554 <- normalize(d.TL$nhitype_2554)
d.TL$indprim_2554 <- normalize(d.TL$indprim_2554)
d.TL$indsec_2554 <- normalize(d.TL$indsec_2554)
d.TL$indtert_2554 <- normalize(d.TL$indtert_2554)




##Table A.6------------------------------------------------------------------------------------


# protectionist bill regressions
reg5.TP <- lm(co ~ dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg6.TP <- lm(co ~ dem + nhitype_2554+ no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg7.TP <- lm(co ~ dem + occpz_low + occpz_mid + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg5.TPint <- lm(co ~ imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg6.TPint <- lm(co ~ nhitype_2554*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg7.TPint <- lm(co ~ occpz_low*dem + occpz_mid*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)


# cluster on member of congress 
c5.TP <- coeftest(reg5.TP, vcov=vcovCL(reg5.TP, factor(d.TP$fips_id)))
c6.TP <- coeftest(reg6.TP, vcov=vcovCL(reg6.TP, factor(d.TP$fips_id)))
c7.TP <- coeftest(reg7.TP, vcov=vcovCL(reg7.TP, factor(d.TP$fips_id)))
c5.TPint <- coeftest(reg5.TPint, vcov=vcovCL(reg5.TPint, factor(d.TP$fips_id)))
c6.TPint <- coeftest(reg6.TPint, vcov=vcovCL(reg6.TPint, factor(d.TP$fips_id)))
c7.TPint <- coeftest(reg7.TPint, vcov=vcovCL(reg7.TPint, factor(d.TP$fips_id)))

# liberalizing bill regressions
reg5.TL <- lm(co ~ dem + imp_MFG + imp_nonMFG + exp_MFG + exp_nonMFG + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg6.TL <- lm(co ~ dem + nhitype_2554 + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg7.TL <- lm(co ~ dem + occpz_low + occpz_mid + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg5.TLint <- lm(co ~ imp_MFG*dem + imp_nonMFG*dem + exp_MFG*dem + exp_nonMFG*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg6.TLint <- lm(co ~ nhitype_2554*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg7.TLint <- lm(co ~ occpz_low*dem + occpz_mid*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)

# cluster on member of congress 
c5.TL <- coeftest(reg5.TL, vcov=vcovCL(reg5.TL, factor(d.TL$fips_id)))
c6.TL <- coeftest(reg6.TL, vcov=vcovCL(reg6.TL, factor(d.TL$fips_id)))
c7.TL <- coeftest(reg7.TL, vcov=vcovCL(reg7.TL, factor(d.TL$fips_id)))
c5.TLint <- coeftest(reg5.TLint, vcov=vcovCL(reg5.TLint, factor(d.TL$fips_id)))
c6.TLint <- coeftest(reg6.TLint, vcov=vcovCL(reg6.TLint, factor(d.TL$fips_id)))
c7.TLint <- coeftest(reg7.TLint, vcov=vcovCL(reg7.TLint, factor(d.TL$fips_id)))


## build table A.6

# protectionist bill table
stargazer(c5.TP, c5.TPint, c6.TP, c6.TPint, c7.TP, c7.TPint, no.space=T, type="text", star.cutoffs = c(0.05, 0.01, 0.001), digits=3)

# liberalizing bill table
stargazer(c5.TL, c5.TLint, c6.TL, c6.TLint, c7.TL, c7.TLint,  no.space=T, type="text", star.cutoffs = c(0.05, 0.01, 0.001), digits=3)

# covariate order and labels for trade bills
cov_keep <- c("dem", "imp_MFG", "imp_nonMFG", "exp_MFG", "exp_nonMFG", "nhitype_2554", "occpz_low", "occpz_mid", "Constant")
cov_ord <- c("^dem$", "^imp_MFG$", "^imp_MFG:dem$","^imp_nonMFG$", "^dem:imp_nonMFG$",
             "^exp_MFG$","^dem:exp_MFG$", "^exp_nonMFG$","^dem:exp_nonMFG$",
             "^nhitype_2554$", "^nhitype_2554:dem$", 
             "^occpz_low$", "^occpz_low:dem$", "^occpz_mid$", "^dem:occpz_mid$", "^Constant$")
cov_lab <- c("Democratic Cosponsor", 
             "Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Non-Manufacturing Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Non-Manufacturing Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Industry Concentration", "\\hspace{10mm} $\\times$ Democrat", 
             "Low-Skill Occupation", "\\hspace{10mm} $\\times$ Democrat", 
             "Mid-Skill Occupation", "\\hspace{10mm} $\\times$ Democrat", 
             "Constant")

# condensed main and interaction effects, latex print
stargazer(c5.TP, c5.TPint, c6.TP, c6.TPint, c7.TP, c7.TPint, c5.TL, c5.TLint, c6.TL, c6.TLint, c7.TL, c7.TLint, 
          no.space=T, type="latex", 
          title = "Linear Regression of Decision to Cosponsor Trade Bills (Non-Duty) on District Characteristics, $109^{th} - 114^{th}$ Congress", 
          out.header = T, star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, dep.var.caption = "Cosponsorship Indicator", 
          column.labels = c("Trade Protectionist", "Trade Liberalizing"), 
          column.separate = c(6, 6), font.size = "scriptsize", 
          notes.append = F, keep = cov_keep, order = cov_ord, covariate.labels = cov_lab, 
          multicolumn = F, label = "tab:mem-tr-appdx")

# additional information for table
# N
cat(c("N", paste(" & ",formatC(c(rep(dim(d.TP)[1], 6), rep(dim(d.TL)[1], 6)), format = "d", big.mark = ","))))

# bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.TP$billno_unique)), 6), rep(length(unique(d.TL$billno_unique)), 6)), format = "d", big.mark = ","))))

# legislators
cat(c("Legislators", paste(" & ",formatC(c(rep(length(unique(d.TP$bioguide_id)), 6), rep(length(unique(d.TL$bioguide_id)), 6)), format = "d", big.mark = ","))))

# R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg5.TP)$r.squared, 
                                    summary(reg5.TPint)$r.squared, 
                                    summary(reg6.TP)$r.squared, 
                                    summary(reg6.TPint)$r.squared, 
                                    summary(reg7.TP)$r.squared, 
                                    summary(reg7.TPint)$r.squared,                                     
                                    summary(reg5.TL)$r.squared, 
                                    summary(reg5.TLint)$r.squared, 
                                    summary(reg6.TL)$r.squared, 
                                    summary(reg6.TLint)$r.squared, 
                                    summary(reg7.TL)$r.squared, 
                                    summary(reg7.TLint)$r.squared), 2))))



##Table A.7----------------------------------------------------------------------------


# protectionist bill regressions
reg2.TP <- lm(co ~ dem + dim1 + dim2 + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg3.TP <- lm(co ~ dem + wtb  + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg4.TP <- lm(co ~ dem + agr + mfg + ent + prf_fin + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TP)
reg3.TPint <- lm(co ~  wtb*dem + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP)
reg4.TPint <- lm(co ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + employed, d= d.TP)


# cluster on member of congress 
c2.TP <- coeftest(reg2.TP, vcov=vcovCL(reg2.TP, factor(d.TP$fips_id)))
c3.TP <- coeftest(reg3.TP, vcov=vcovCL(reg3.TP, factor(d.TP$fips_id)))
c4.TP <- coeftest(reg4.TP, vcov=vcovCL(reg4.TP, factor(d.TP$fips_id)))
c3.TPint <- coeftest(reg3.TPint, vcov=vcovCL(reg3.TPint, factor(d.TP$fips_id)))
c4.TPint <- coeftest(reg4.TPint, vcov=vcovCL(reg4.TPint, factor(d.TP$fips_id)))

# liberalizing bill regressions
reg2.TL <- lm(co ~ dem + dim1 + dim2 + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg3.TL <- lm(co ~ dem + wtb + as.factor(congress)  + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg4.TL <- lm(co ~ dem + agr + mfg + ent + prf_fin + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL)
reg3.TLint <- lm(co ~  wtb*dem + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL)
reg4.TLint <- lm(co ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + as.factor(congress) + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + employed, d= d.TL)

# cluster on member of congress 
c2.TL <- coeftest(reg2.TL, vcov=vcovCL(reg2.TL, factor(d.TL$fips_id)))
c3.TL <- coeftest(reg3.TL, vcov=vcovCL(reg3.TL, factor(d.TL$fips_id)))
c4.TL <- coeftest(reg4.TL, vcov=vcovCL(reg4.TL, factor(d.TL$fips_id)))
c3.TLint <- coeftest(reg3.TLint, vcov=vcovCL(reg3.TLint, factor(d.TL$fips_id)))
c4.TLint <- coeftest(reg4.TLint, vcov=vcovCL(reg4.TLint, factor(d.TL$fips_id)))

# protectionist bill table
stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, no.space=T, type="text", star.cutoffs = c(0.05, 0.01, 0.001), digits=3)

# liberalizing bill table
stargazer(c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint, no.space=T, type="text", star.cutoffs = c(0.05, 0.01, 0.001), digits=3)

#covariate order and labels for trade bills
cov_keep <- c("dem", "dim1", "dim2", "wtb", "agr", "mfg", "ent", "prf_fin", "Constant")
cov_ord <- c("^dem$", "^dim1$", "^dim2$", "^wtb$", "^wtb:dem$", "^agr$", "^agr:dem$", 
             "^mfg$", "^dem:mfg$", "^ent$", "^dem:ent$", "^prf_fin$", "^dem:prf_fin$", "^Constant$")
cov_lab <- c("Democratic Cosponsor", "DW Nominate Dim. 1", "DW Nominate Dim. 2", 
             "Trade Balance", "\\hspace{10mm} $\\times$ Democrat", 
             "Agriculture", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing", "\\hspace{10mm} $\\times$ Democrat", 
             "Entertainment", "\\hspace{10mm} $\\times$ Democrat", 
             "Professional and Financial", "\\hspace{10mm} $\\times$ Democrat", 
             "Constant")


# condensed main and interaction effects, latex print
stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint,
          no.space=T, type="latex", 
          title = "Linear Regression of Decision to Cosponsor Trade Bills (Non-Duty) with Fixed Effects by Congress, $109^{th} - 114^{th}$ Congress", 
          out.header = T, star.cutoffs = c(0.05, 0.01, 0.001), 
          digits=3, dep.var.caption = "Cosponsorship Indicator", 
          column.labels = c("Trade Protectionist", "Trade Liberalizing"), 
          column.separate = c(5, 5), font.size = "scriptsize", 
          notes.append = F, keep = cov_keep, order = cov_ord, covariate.labels = cov_lab, 
          multicolumn = F, label = "tab:mem-tr-fe-appdx")


# additional information for table
# N
cat(c("N", paste(" & ",formatC(c(rep(dim(d.TP)[1], 5), rep(dim(d.TL)[1], 5)), format = "d", big.mark = ","))))

# bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.TP$billno_unique)), 5), rep(length(unique(d.TL$billno_unique)), 5)), format = "d", big.mark = ","))))

# legislators
cat(c("Legislators", paste(" & ",formatC(c(rep(length(unique(d.TP$bioguide_id)), 5), rep(length(unique(d.TL$bioguide_id)), 5)), format = "d", big.mark = ","))))

# R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg5.TP)$r.squared, 
                                    summary(reg5.TPint)$r.squared, 
                                    summary(reg6.TP)$r.squared, 
                                    summary(reg6.TPint)$r.squared, 
                                    summary(reg7.TP)$r.squared, 
                                    summary(reg7.TPint)$r.squared,                                     
                                    summary(reg5.TL)$r.squared, 
                                    summary(reg5.TLint)$r.squared, 
                                    summary(reg6.TL)$r.squared, 
                                    summary(reg6.TLint)$r.squared, 
                                    summary(reg7.TL)$r.squared, 
                                    summary(reg7.TLint)$r.squared), 2))))





##Table A.8-----------------------------------------------------------------------------------


## How are the data distributed?

# data (bivariate)
plot(d.TP$exp, jitter(d.TP$co, factor = .1), pch = ".", xlab = "exports", ylab = "cosponsorship indicator")

# fitted (full model)
log3.TP <- glm(co ~ dem + imp + exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d=d.TP, family = 'binomial')
summary(log3.TP)
glm.probs <- predict(log3.TP,type = "response")
glm.pred <- ifelse(glm.probs > 0.5, "cosp (1)", "no (0)")
table(glm.pred, d.TP$co)
plot(d.TP$exp, glm.probs,  pch = ".")


## logistic regressions and clustered standard errors

## protectionist bill logistic regressions
log2.TP <- glm(co ~ dem + dim1 + dim2 + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d=d.TP, family = 'binomial')
log3.TP <- glm(co ~ dem + imp + exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d=d.TP, family = 'binomial')
log4.TP <- glm(co ~ dem + agr + mfg + ent + prf_fin + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d=d.TP, family = 'binomial')
log3.TPint <- glm(co ~  imp*dem + exp*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d=d.TP, family = 'binomial')
log4.TPint <- glm(co ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d=d.TP, family = 'binomial')

# cluster on member of congress
c2.TP <- coeftest(log2.TP, vcov. = vcovCL(log2.TP, cluster= d.TP$fips_id, type = "HC0"))
c3.TP <- coeftest(log3.TP, vcov. = vcovCL(log3.TP, cluster= d.TP$fips_id, type = "HC0"))
c4.TP <- coeftest(log4.TP, vcov. = vcovCL(log4.TP, cluster= d.TP$fips_id, type = "HC0"))
c3.TPint <- coeftest(log3.TPint, vcov. = vcovCL(log3.TPint, cluster=d.TP$fips_id, type = "HC0"))
c4.TPint <- coeftest(log4.TPint, vcov. = vcovCL(log4.TPint, cluster=d.TP$fips_id, type = "HC0"))

## liberalizing bill logistic regressions
log2.TL <- glm(co ~ dem + dim1 + dim2 + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL, family = 'binomial')
log3.TL <- glm(co ~ dem + imp + exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL, family = 'binomial')
log4.TL <- glm(co ~ dem + agr + mfg + ent + prf_fin + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL, family = 'binomial')
log3.TLint <- glm(co ~  imp*dem + exp*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL, family = 'binomial')
log4.TLint <- glm(co ~ agr*dem + mfg*dem + ent*dem + prf_fin*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority  + income + employed, d= d.TL, family = 'binomial')

# cluster on member of congress
c2.TL <- coeftest(log2.TL, vcov. = vcovCL(log2.TL, cluster = d.TL$fips_id, type = "HC0"))
c3.TL <- coeftest(log3.TL, vcov. = vcovCL(log3.TL, cluster = d.TL$fips_id, type = "HC0"))
c4.TL <- coeftest(log4.TL, vcov. = vcovCL(log4.TL, cluster = d.TL$fips_id, type = "HC0"))
c3.TLint <- coeftest(log3.TLint, vcov. = vcovCL(log3.TLint, cluster = d.TL$fips_id, type = "HC0"))
c4.TLint <- coeftest(log4.TLint, vcov. = vcovCL(log4.TLint, cluster = d.TL$fips_id, type = "HC0"))


##COMBINED/CONDENSED TRADE TABLE

# protectionist bill table
stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, no.space=T, type="text", star.cutoffs = c(0.05, 0.01, 0.001), digits=3)

# liberalizing bill table
stargazer(c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint,  no.space=T, type="text", star.cutoffs = c(0.05, 0.01, 0.001), digits=3)


#covariate order and labels for trade bills
cov_keep <- c("dem", "dim1", "dim2", "imp", "exp", "agr", "mfg", "ent", "prf_fin", "Constant")
cov_ord <- c("^dem$", "^dim1$", "^dim2$", "^imp$", "^imp:dem$","^exp$","^dem:exp$", "^agr$", "^agr:dem$", 
             "^mfg$", "^dem:mfg$", "^ent$", "^dem:ent$", "^prf_fin$", "^dem:prf_fin$", "^Constant$")
cov_lab <- c("Democratic Cosponsor", "DW Nominate Dim. 1", "DW Nominate Dim. 2", 
             "Imports", "\\hspace{10mm} $\\times$ Democrat", 
             "Exports", "\\hspace{10mm} $\\times$ Democrat", 
             "Agriculture", "\\hspace{10mm} $\\times$ Democrat", 
             "Manufacturing", "\\hspace{10mm} $\\times$ Democrat", 
             "Entertainment", "\\hspace{10mm} $\\times$ Democrat", 
             "Professional and Financial", "\\hspace{10mm} $\\times$ Democrat", 
             "Constant")



#condensed main and interaction effects, latex print
stargazer(c2.TP, c3.TP, c3.TPint, c4.TP, c4.TPint, c2.TL, c3.TL, c3.TLint, c4.TL, c4.TLint, no.space=T, type="latex", title = "Linear Regression of Decision to Cosponsor Trade Bills (Non-Duty) on District Characteristics, $109^{th} - 114^{th}$ Congress", out.header = T, star.cutoffs = c(0.05, 0.01, 0.001), digits=3, dep.var.caption = "Cosponsorship Indicator", column.labels = c("Trade Protectionist", "Trade Liberalizing"), column.separate = c(5, 5), font.size = "scriptsize", notes.append = F, keep = cov_keep, order = cov_ord, covariate.labels = cov_lab, multicolumn = F, label = "tab:mem-tr")


#additional information for table
#N
cat(c("N", paste(" & ",formatC(c(rep(dim(d.TP)[1], 5), rep(dim(d.TL)[1], 5)), format = "d", big.mark = ","))))

#bills
cat(c("Bills", paste(" & ",formatC(c(rep(length(unique(d.TP$billno_unique)), 5), rep(length(unique(d.TL$billno_unique)), 5)), format = "d", big.mark = ","))))

#legislators
cat(c("Legislators", paste(" & ",formatC(c(rep(length(unique(d.TP$bioguide_id)), 5), rep(length(unique(d.TL$bioguide_id)), 5)), format = "d", big.mark = ","))))

#Log Likelihood
cat(c("Log Lik.", paste(" & ", round(c(logLik(log2.TP), 
                                       logLik(log3.TP), logLik(log3.TPint), 
                                       logLik(log4.TP), logLik(log4.TPint), 
                                       logLik(log2.TL), 
                                       logLik(log3.TL), logLik(log3.TLint), 
                                       logLik(log4.TL), logLik(log4.TLint)),2))))





##Table A.9-----------------------------------------------------------------------------------

# create indicator for pre-2008 period in coponsosorship data for protectionist and liberalizing bills
d.TP$pre_crisis <- ifelse(d.TP$congress<111,1,0)
d.TL$pre_crisis <- ifelse(d.TL$congress<111,1,0)

# regressions for pre- and post-2008 cosponsorship data, trade protectionist bills
reg3.TPint.pre <- lm(co ~ dem*imp + dem*exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP[d.TP$pre_crisis==1,])
reg3.TPint.post <- lm(co ~ dem*imp + dem*exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TP[d.TP$pre_crisis==0,])

# regressions for pre- and post-2008 cosponsorship data, trade liberalizing bills
reg3.TLint.pre <- lm(co ~ dem*imp + dem*exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL[d.TL$pre_crisis==1,])
reg3.TLint.post <- lm(co ~ dem*imp + dem*exp + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, d= d.TL[d.TL$pre_crisis==0,])

# cluster by member of congress
c3.TPint.pre <- coeftest(reg3.TPint.pre, vcov. = vcovCL(reg3.TPint.pre, cluster = d.TP$fips_id[d.TP$pre_crisis==1], type = "HC0"))
c3.TPint.post <- coeftest(reg3.TPint.post, vcov. = vcovCL(reg3.TPint.post, cluster = d.TP$fips_id[d.TP$pre_crisis==0], type = "HC0"))
c3.TLint.pre <- coeftest(reg3.TLint.pre, vcov. = vcovCL(reg3.TLint.pre, cluster = d.TL$fips_id[d.TL$pre_crisis==1], type = "HC0"))
c3.TLint.post <- coeftest(reg3.TLint.post, vcov. = vcovCL(reg3.TLint.post, cluster = d.TL$fips_id[d.TL$pre_crisis==0], type = "HC0"))

# table 
stargazer(c3.TPint.pre, c3.TPint.post, c3.TLint.pre, c3.TLint.post, type = "text", no.space = T,
          star.cutoffs = c(0.05, 0.01, 0.001), digits=3, dep.var.caption = "Cosponsorship Indicator", 
          column.labels = c("Trade Protectionist", "Trade Liberalizing"), column.separate = c(2,2), 
          font.size = "scriptsize", multicolumn = F)


#covariate order and labels for trade bills
cov_keep <- c("dem", "imp", "exp", "Constant")
cov_ord <- c("^dem$", "^imp$", "^dem:imp$", "^exp$", "^dem:exp$", "^Constant$")
cov_lab <- c("Democratic Cosponsor", "Imports", "\\hspace{10mm} $\\times$ Democrat", "Exports", "\\hspace{10mm} $\\times$ Democrat", "Constant")

#condensed main and interaction effects, latex print

stargazer(c3.TPint.pre, c3.TPint.post, c3.TLint.pre, c3.TLint.post, type = "latex", no.space = T,
          star.cutoffs = c(0.05, 0.01, 0.001), digits=3, dep.var.caption = "Cosponsorship Indicator", 
          column.labels = c("Trade Protectionist", "Trade Liberalizing"), column.separate = c(2,2), 
          font.size = "scriptsize", notes.append = T, keep = cov_keep, order = cov_ord, 
          covariate.labels = cov_lab, multicolumn = F, label = "tab:mem-tr-2008crisis")

#additional information for table
#N
dim(d.TP[d.TP$pre_crisis==1,])[1]
dim(d.TP[d.TP$pre_crisis==0,])[1]
dim(d.TL[d.TL$pre_crisis==1,])[1]
dim(d.TL[d.TL$pre_crisis==0,])[1]


#bills
cat(c("Bills", paste(" & ",formatC(c((length(unique(d.TP$billno_unique[d.TP$pre_crisis==1]))),
                                     (length(unique(d.TP$billno_unique[d.TP$pre_crisis==0]))),
                                     (length(unique(d.TL$billno_unique[d.TL$pre_crisis==1]))), 
                                     (length(unique(d.TL$billno_unique[d.TL$pre_crisis==0])))),
                                   format = "d", big.mark = ","))))

#legislators
cat(c("Legislators", paste(" & ",formatC(c((length(unique(d.TP$bioguide_id[d.TP$pre_crisis==1]))),
                                           (length(unique(d.TP$bioguide_id[d.TP$pre_crisis==0]))),
                                           (length(unique(d.TL$bioguide_id[d.TL$pre_crisis==1]))),
                                           (length(unique(d.TL$bioguide_id[d.TL$pre_crisis==0])))), 
                                         format = "d", big.mark = ","))))

#R-squared
cat(c("$R^2$", paste(" & ", round(c(summary(reg3.TPint.pre)$r.squared, summary(reg3.TPint.post)$r.squared, 
                                    summary(reg3.TLint.pre)$r.squared, summary(reg3.TLint.post)$r.squared), 2))))


