## Adrienne Hosek and Lauren Peritz ----------------------------------------
## QJPS 2021 "Local labor markets and party elite"
## Purpose: Replicate Appendix Figure A1
## Update: 15 June 2021

## Preliminary steps -------------------------------------------------------
rm(list=ls(all=T))

# Set your working directory here in place of "~/MyFilePath"
setwd("~/MyFilePath/AH_LP_qjps2021_replication")

# packages
library(Zelig)

# Load sponsor data 
load("HouseSponsorData.RData")


## Figure A1: policy position of trade bills by sponsor's dw-nominate -----------------------

## bill sponsorship frequency and content by ideology (dw-nominate, dimension 1)
breaks <- seq(-.9, 1, .1)
d$dim1simplify <- vector("numeric", dim(d)[1])

for(i in length(breaks):1){
  d$dim1simplify[d$dim1 <= breaks[i]] <- i
}


## non-duty trade bills
mcontent <-with(subset(d, policy.content.final != 0 & duty == 0), tapply(policy.content.final, list(dim1simplify, congress), mean))
nbills <- with(subset(d, policy.content.final != 0 & duty == 0), tapply(policy.content.final, list(dim1simplify, congress), length))

x <- rownames(nbills)
na <- apply(mcontent, 2, function(k) !is.na(k))
congress <- c(109:114)


## plot 109th Congress

pdf("FigureA1-109.pdf")
i <- 1
par(mar = c(7,6,1,1))  
plot(x[na[,i]], nbills[na[,i],i], ylab = NA, xlab = NA, axes = F, type = "h", lwd = 10, col = rgb(1 - (na.omit(mcontent[,i]) + 1)/2, 0, (na.omit(mcontent[,i]) + 1)/2, alpha = .5), xlim = c(1, 20), ylim = c(0, 50), cex.lab = 2)

mtext("dw-nominate, dim 1", side = 1, line = 4, cex = 2)
mtext("number of bills", side = 2, line = 4, cex = 2)
axis(1, at = c(1, 10, 20), labels = c(-1, 0, 1), cex.axis = 1.5)
axis(2, cex.axis = 1.5)
dev.off()

## plot 112th Congress

pdf("FigureA1-112.pdf")
i <- 4
par(mar = c(7,6,1,1))  
plot(x[na[,i]], nbills[na[,i],i], ylab = NA, xlab = NA, axes = F, type = "h", lwd = 10, col = rgb(1 - (na.omit(mcontent[,i]) + 1)/2, 0, (na.omit(mcontent[,i]) + 1)/2, alpha = .5), xlim = c(1, 20), ylim = c(0, 50), cex.lab = 2)

mtext("dw-nominate, dim 1", side = 1, line = 4, cex = 2)
mtext("number of bills", side = 2, line = 4, cex = 2)
axis(1, at = c(1, 10, 20), labels = c(-1, 0, 1), cex.axis = 1.5, padj = 0)
axis(2, cex.axis = 1.5)
dev.off()

## plot 110, 111, 113, 114 congresses
for(i in c(2,3,5,6)){
  pdf(paste("FigureA1-", congress[i], ".pdf", sep = ""))
  par(mar = c(7,6,1,1)) 
  plot(x[na[,i]], nbills[na[,i],i], ylab = NA, xlab = NA, axes = F, type = "h", lwd = 10, col = rgb(1 - (na.omit(mcontent[,i]) + 1)/2, 0, (na.omit(mcontent[,i]) + 1)/2, alpha = .5), xlim = c(1, 20), ylim = c(0, 50))
  
  axis(1, at = c(1, 10, 20), labels = c(-1, 0, 1), cex.axis = 1.5)
  dev.off()
}

