## Adrienne Hosek and Lauren Peritz ----------------------------------------
## QJPS 2021 "Local labor markets and party elite"
## Purpose: Replicate Appendix Figure A2
## Update: 15 June 2021

## Preliminary steps -------------------------------------------------------
rm(list=ls(all=T))

# Set your working directory here in place of "~/MyFilePath"
setwd("~/MyFilePath/AH_LP_qjps2021_replication")

# Load Roll Call data 
load("HouseRollCallData.RData")

## Figure A.2: Roll call vote counts by party for each trade bill -----------------------------

## Assemble data

# protectionist
d.TP <- d[d$policy.content.final == 1, 
          c("billno_unique","bioguide_id",
            "vote_position", "support",
            "policy.content.final","dem"
          )]

d.TP$vote_position_simp <- as.factor(ifelse(d.TP$vote_position=="Speaker", "Yes",d.TP$vote_position))


# liberalizing
d.TL <- d[d$policy.content.final == -1, 
          c("billno_unique","bioguide_id",
            "vote_position", "support",
            "policy.content.final","dem"
          )]

d.TL$vote_position_simp <- as.factor(ifelse(d.TL$vote_position=="Speaker", "Yes",
                                            ifelse(d.TL$vote_position=="Present", "No", d.TL$vote_position)))



## Table of RC Vote on PROTECTIONIST bills by party

b <- unique(d.TP$billno_unique)
TP.v <- as.data.frame(matrix(NA, nrow = length(b), ncol = 5))
rownames(TP.v) <- b
TP.v[,1] <- paste(substring(b,1,3),substring(b,4,7),sep="-")
colnames(TP.v) <- c("bill", "R_No", "R_Yes","D_No", "D_Yes")

for(i in 1:5){
  temp <- d.TP[d.TP$billno_unique==b[i],]
  TP.v[i,2:3] <- summary(temp$vote_position_simp[temp$dem==0])
  TP.v[i,4:5] <- summary(temp$vote_position_simp[temp$dem==1])
}

TP.v


## (a) Plot RC Vote on PROTECTIONIST bills by party

pdf("FigureA2-a.pdf")
par(mar = c(2,2,2,2))
plot(x = 999, y = 999, xlim = c(-325, 425), ylim = c(0,16), xlab = NA, ylab = NA, axes= F)
abline(v = 0)

for(i in 0:4){
  rect(xleft = -(TP.v[i+1,2]+TP.v[i+1,4]), xright = -TP.v[i+1,4], ybottom = i, ytop = i +.9, col = "darkred")
  rect(xleft = -TP.v[i+1,4], xright = 0, ybottom = i, ytop = i+.9, col = "darkblue")
  rect(xleft=0, xright =TP.v[i+1,5], ybottom = i, ytop = i+.9, col = rgb(0,0,1, alpha = .5) )
  rect(xleft = TP.v[i+1,5], xright = TP.v[i+1,5]+TP.v[i+1,3], ybottom = i, ytop = i+.9, col = rgb(1,0,0, alpha = .5))
}

text(labels = TP.v[,1], x = -300, y = seq(0.5,4.5, 1), cex = .9)
text(labels = "Congress-Bill", x=-275, y = 16.25, font = 2)
text(labels = "No", x=-30, y = 16.25, font = 2)
text(labels = "Yes", x=35, y = 16.25, font = 2)

mtext(text = c(200, 0, 200, 400), side = 1, line = 1, at = seq(-200,400, by = 200) )
dev.off()

## Table of RC Vote on LIBERALIZING bills by party

b <- unique(d.TL$billno_unique)
TL.v <- as.data.frame(matrix(NA, nrow = length(b), ncol = 5))
rownames(TL.v) <- b
TL.v[,1] <- paste(substring(b,1,3),substring(b,4,7),sep="-")
colnames(TL.v) <- c("bill", "R_No", "R_Yes","D_No", "D_Yes")

for(i in 1:length(b)){
  temp <- d.TL[d.TL$billno_unique==b[i],]
  TL.v[i,2:3] <- summary(temp$vote_position_simp[temp$dem==0])
  TL.v[i,4:5] <- summary(temp$vote_position_simp[temp$dem==1])
}

TL.v


## (b) Plot RC Vote on LIBERALIZING bills by party 

pdf("FigureA2-b.pdf")
par(mar = c(2,2,2,2))
plot(x = 999, y = 999, xlim = c(-325, 425), ylim = c(0,16), xlab = NA, ylab = NA, axes= F)
abline(v = 0)

for(i in 0:15){
  rect(xleft = -(TL.v[i+1,2]+TL.v[i+1,4]), xright = -TL.v[i+1,4], ybottom = i, ytop = i +.9, col = "darkred")
  rect(xleft = -TL.v[i+1,4], xright = 0, ybottom = i, ytop = i+.9, col = "darkblue")
  rect(xleft=0, xright =TL.v[i+1,5], ybottom = i, ytop = i+.9, col = rgb(0,0,1, alpha = .5) )
  rect(xleft = TL.v[i+1,5], xright = TL.v[i+1,5]+TL.v[i+1,3], ybottom = i, ytop = i+.9, col = rgb(1,0,0, alpha = .5))
}

text(labels = TL.v[,1], x = -300, y = seq(0.5,15.5, 1), cex = .9)
text(labels = "Congress-Bill", x=-275, y = 16.25, font = 2)
text(labels = "No", x=-30, y = 16.25, font = 2)
text(labels = "Yes", x=35, y = 16.25, font = 2)

mtext(text = c(200, 0, 200, 400), side = 1, line = 1, at = seq(-200,400, by = 200) )
dev.off()
