## Adrienne Hosek and Lauren Peritz ----------------------------------------
## QJPS 2021 "Local labor markets and party elite"
## Purpose: Replicate Appendix Figure A3
## Update: 15 June 2021



## Preliminary steps -------------------------------------------------------
rm(list=ls(all=T))

# Set your working directory here in place of "~/MyFilePath"
setwd("~/MyFilePath/AH_LP_qjps2021_replication")

# packages
library(ggplot2)


# Load member data
load("HouseMemberData.RData")

# one observation per member of congress; drop bill information
dtr <- unique(subset(d, select = c("fips_id","bioguide_id","dem","AGR_2554", "ENT_2554", "MFG_2554", "prf_fin", "exp", "imp" )))


## Figure A.3: Density plots for economic variables -------------------------

## (a) - Agriculture employment, AGR_2554
dD <- density(dtr$AGR_2554[dtr$dem == 1])
dR <- density(dtr$AGR_2554[dtr$dem == 0])

pdf("FigureA3-a.pdf")
plot(dR, col = rgb(1,0,0,.2), xlab = "Agricultural Employment", main = NA, ylim = c(0, 100), xlim = range(dtr$AGR_2554))
lines(dD, col = rgb(0,0,1,.2))
polygon(dR, col = rgb(1,0,0,.2), border = "red")
polygon(dD, col = rgb(0,0,1,.2), border = "blue")
dev.off()

## (b) - Entertainment employment, ENT_2554
dD <- density(dtr$ENT_2554[dtr$dem == 1])
dR <- density(dtr$ENT_2554[dtr$dem == 0])

pdf("FigureA3-b.pdf")
plot(dR, col = rgb(1,0,0,.2), xlab = "Entertainment Employment", ylim = c(0, 30), main = NA, xlim = range(dtr$ENT_2554))
lines(dD, col = rgb(0,0,1,.2))
polygon(dR, col = rgb(1,0,0,.2), border = "red")
polygon(dD, col = rgb(0,0,1,.2), border = "blue")
dev.off()

## (c) - Manufacturing employment, MFG_2554
dD <- density(dtr$MFG_2554[dtr$dem == 1])
dR <- density(dtr$MFG_2554[dtr$dem == 0])

pdf("FigureA3-c.pdf")
plot(dR, col = rgb(1,0,0,.2), xlab = "Manufacturing Employment", ylim = c(0, 10), main = NA, xlim = range(dtr$MFG_2554))
lines(dD, col = rgb(0,0,1,.2))
polygon(dR, col = rgb(1,0,0,.2), border = "red")
polygon(dD, col = rgb(0,0,1,.2), border = "blue")
dev.off()

## (d) - Professional and financial employment, prf_fin 
dD <- density(dtr$prf_fin[dtr$dem == 1])
dR <- density(dtr$prf_fin[dtr$dem == 0])


pdf("FigureA3-d.pdf")
plot(dR, col = rgb(1,0,0,.2), xlab = "Professional and Financial Employment", ylim = c(0, 10), main = NA, xlim = range(dtr$prf_fin))
lines(dD, col = rgb(0,0,1,.2))
polygon(dR, col = rgb(1,0,0,.2), border = "red")
polygon(dD, col = rgb(0,0,1,.2), border = "blue")
dev.off()

## (e) - Employment weighted exports, exp
dD <- density(dtr$exp[dtr$dem == 1])
dR <- density(dtr$exp[dtr$dem == 0])

pdf("FigureA3-e.pdf")
plot(dR, col = rgb(1,0,0,.2), xlab = "Employment-Weighted Exports", main = NA, xlim = c(-2,10), ylim = c(0,1))
lines(dD, col = rgb(0,0,1,.2))
polygon(dR, col = rgb(1,0,0,.2), border = "red")
polygon(dD, col = rgb(0,0,1,.2), border = "blue")
dev.off()

## (f) - Employment weighted imports, imp
dD <- density(dtr$imp[dtr$dem == 1])
dR <- density(dtr$imp[dtr$dem == 0])

pdf("FigureA3-f.pdf")
plot(dR, col = rgb(1,0,0,.2), xlab = "Employment-Weighted Imports", main = NA, xlim = c(-2,10), ylim = c(0, 1))
lines(dD, col = rgb(0,0,1,.2))
polygon(dR, col = rgb(1,0,0,.2), border = "red")
polygon(dD, col = rgb(0,0,1,.2), border = "blue")
dev.off()








