## Adrienne Hosek and Lauren Peritz ----------------------------------------
## QJPS 2021 "Local labor markets and party elite"
## Purpose: Replicate Appendix Figure A4
## Update: 15 June 2021

## Preliminary steps -------------------------------------------------------
rm(list=ls(all=T))

# Set your working directory here in place of "~/MyFilePath"
setwd("~/MyFilePath/AH_LP_qjps2021_replication")

# packages
library(Zelig)

# Load cosponsor data 
load("HouseMemberData.RData")

# drop neutral bills
d <- d[d$policy.content.final!= 0,]

# function to normalize the explanatory variables for each model
normalize <- function(var){(var - mean(var))/sd(var)}



## Assemble data -----------------------------------------------------------

# protectionist bills
d.TP <- d[d$duty==0 & d$sp == 0 & d$policy.content.final == 1, 
          c("co", "no.cosponsor", "dem", "samepartysp", "sp_gatekeeper", "sp_majority", 
            "policy.content.final", "fips_id", "dim1", "dim2", "billno_unique", "bioguide_id","congress")]

d.TP$wtb <-  normalize(d$wtb[d$duty==0 & d$sp == 0 & d$policy.content.final == 1])
d.TP$income <- normalize(log(d$income[d$duty==0 & d$sp == 0 & d$policy.content.final == 1]))
d.TP$employed <- normalize(d$employed2554[d$duty==0 & d$sp == 0 & d$policy.content.final == 1])

# liberalizing bills
d.TL <- d[d$duty==0 & d$sp == 0 & d$policy.content.final == -1, 
          c("co", "no.cosponsor", "dem", "samepartysp", "sp_gatekeeper", "sp_majority", 
            "policy.content.final", "fips_id", "dim1", "dim2", "billno_unique", "bioguide_id","congress")]

d.TL$wtb <-  normalize(d$wtb[d$duty==0 & d$sp == 0 & d$policy.content.final == -1])
d.TL$income <- normalize(log(d$income[d$duty==0 & d$sp == 0 & d$policy.content.final == -1]))
d.TL$employed <- normalize(d$employed2554[d$duty==0 & d$sp == 0 & d$policy.content.final == -1])


## Expected Value for PROTECTION bills --------------------------------

z.TPint <- zelig(co ~  wtb*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, 
                  model = "normal.gee", id = "fips_id", data = d.TP, cite = F)
summary(z.TPint)

# compare dem v. rep, trade range
wtb.range <- seq(round(min(d.TP$wtb),1), round(max(d.TP$wtb),1), by = .1)
x.hi <- setx(z.TPint, dem = 1, wtb = wtb.range)
x.lo <- setx(z.TPint, dem = 0, wtb = wtb.range)

# EV as function of dem:wtb
s.out.TP <- sim(z.TPint, x = x.hi, x1 = x.lo)

# plot EV with confidence intervals
pdf("FigureA4-a.pdf")
ci.plot(s.out.TP, var = "wtb", xlab = "Weighted Trade Balance (normalized)",ylab="Expected Value - Cosponorship",
        ci = c(90, 95, 99), leg=4, ylim = c(0,.15), xlim = c(-6,6))
dev.off()


## Expected Value for LIBERALIZING bills --------------------------------

z.TLint <- zelig(co ~  wtb*dem + no.cosponsor + samepartysp + sp_gatekeeper + sp_majority + income + employed, 
                  model = "normal.gee", id = "fips_id", data = d.TL, cite = F)
summary(z.TLint)

# compare dem v. rep, trade range
wtb.range <- seq(round(min(d.TL$wtb),1), round(max(d.TL$wtb),1), by = .1)
x.hi <- setx(z.TLint, dem = 1, wtb = wtb.range)
x.lo <- setx(z.TLint, dem = 0, wtb = wtb.range)

# expected values as function of dem:wtb
s.out.TL <- sim(z.TLint, x = x.hi, x1 = x.lo)

# plot EV with confidence intervals
pdf("FigureA4-b.pdf")
ci.plot(s.out.TL, var = "wtb", xlab = "Weighted Trade Balance (normalized)",ylab="Expected Value - Cosponorship",
        ci = c(90, 95, 99), leg=4, ylim = c(0,.15), lim = c(-6,6))
dev.off()


